// Copyright (c) 2023 VMware Carbon Black, all rights reserved

package poke

import (
	"bytes"
	"io"
	"log"
	"net/http"
	"os"
	"testing"

	. "github.com/onsi/ginkgo/v2"
	"hello-api/internal/utils"
	//nolint:goimports  // this is ours
)

var ginkoLogger = log.New(GinkgoWriter, "", log.Default().Flags())

func getEndpoint(isReady bool) string {
	addReady := ""
	if isReady {
		addReady = "?isReady"
	}
	_, found := os.LookupEnv("IS_LOCAL_TEST") // flag; define to mark as local run
	if found {
		return "http://localhost:8080/hello-api/healthCheck" + addReady
	}
	return "http://ems-device-hello/hello-api/healthCheck" + addReady
}

func TestHealthCheck(t *testing.T) {
	ginkoLogger.Printf(utils.HeaderStr("Health Check"))

	client := http.DefaultClient
	healthCheckRequest, _ := http.NewRequest("GET", getEndpoint(false), http.NoBody)
	response, err := client.Do(healthCheckRequest)
	if err != nil {
		t.Fatalf("Health check call failed, %v", err)
	}
	//goland:noinspection GoUnhandledErrorResult
	defer response.Body.Close()

	var buffer bytes.Buffer
	_, err = io.Copy(&buffer, response.Body)
	if err != nil {
		t.Fatalf("Response body read failure")
	}
	ginkoLogger.Printf("RESPONSE: %+v", response)
	if response.StatusCode != 200 {
		t.Fatalf("Health check test failed %d: %s", response.StatusCode, buffer.String())
	}
}

func TestHealthCheckReady(t *testing.T) {
	ginkoLogger.Printf(utils.HeaderStr("Health Check with isReady"))

	client := http.DefaultClient
	healthCheckRequest, _ := http.NewRequest("GET", getEndpoint(true), http.NoBody)
	response, err := client.Do(healthCheckRequest)
	if err != nil {
		t.Fatalf("Health check call failed, %v", err)
	}

	//goland:noinspection GoUnhandledErrorResult
	defer response.Body.Close()

	var buffer bytes.Buffer
	_, err = io.Copy(&buffer, response.Body)
	if err != nil {
		t.Fatalf("Response body read failure")
	}
	ginkoLogger.Printf("RESPONSE: %+v", response)
	if response.StatusCode != 200 {
		t.Fatalf("Health check test failed %d: %s", response.StatusCode, buffer.String())
	}
}
